@@ -5,8 +5,9 @@ from __future__ import unicode_literals
 from django import forms
 from django.utils import timezone
 
-import djconfig
-from djconfig.models import Config
+from . import conf
+from . import registry
+from . import models
 
 
 class ConfigForm(forms.Form):
@@ -19,7 +20,7 @@ class ConfigForm(forms.Form):
     def __init__(self, *args, **kwargs):
         super(ConfigForm, self).__init__(*args, **kwargs)
 
-        self.initial = {field_name: getattr(djconfig.config, field_name)
+        self.initial = {field_name: getattr(conf.config, field_name)
                         for field_name in self.fields}
 
     def save(self):
@@ -27,9 +28,9 @@ class ConfigForm(forms.Form):
         data['_updated_at'] = timezone.now()
 
         for field_name, value in data.items():
-            count = Config.objects.filter(key=field_name).update(value=value)
+            count = models.Config.objects.filter(key=field_name).update(value=value)
 
             if not count:
-                Config.objects.create(key=field_name, value=value)
+                models.Config.objects.create(key=field_name, value=value)
 
-        djconfig.load()
+        registry.load()
